==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/sblock/scroll.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR);
$VAR['Content'] = "";
if ($story) {
   if ($row = SqlResult("SELECT Topic FROM T_Stories WHERE Rid = '$story'")) {
      $VAR['Heading'] = _TOPIC . " : " . $TOPIC[$row]['Topic'];
      $VAR['Content'] .="<B>" . _LAST_STORY . "</B><BR>\n";

	   if ($agent['br'] == "MOZL6" || $agent['br'] == "TXT")
         $VAR['Content'] .= KWL_NewStory($story,1);
      else $VAR['Content'] .="<IMG NAME=\"placeholder\" SRC=\"$CONF[G_URL]/images.d/speck.gif\" BORDER=0 HEIGHT=42 VSPACE=0 HSPACE=0 ALT=\"". _LAST_STORY ."\">\n";

      $VAR['Content'] .= "<HR WIDTH=\"95%\">\n";
      $VAR['Content'] .= "<B>" . _TOP5 . "</B>";

      $sql = "SELECT Rid,Heading,replys FROM T_Stories WHERE Topic = $row ORDER by Hits DESC LIMIT 1";
      $A = SqlQueryFetchArray($sql);
      if (is_array($A)) {
         $VAR['Content'] .= "<BR>$CONF[dotchar]<A HREF=\"". KWL_MakeStoryLink($A["Rid"]) ."\">$A[Heading]</A> ($A[replys])\n";
      }

      $sql = "SELECT Rid,Heading,replys FROM T_Stories WHERE Topic = $row ORDER by replys DESC LIMIT 1";
      $A = SqlQueryFetchArray($sql);
      if (is_array($A)) {
         $VAR['Content'] .= "<HR WIDTH=\"95%\"><B>" . _HOT5 . "</B><BR>".
                          "$CONF[dotchar]<A HREF=\"". KWL_MakeStoryLink($A["Rid"]) ."\">$A[Heading]</A> ($A[replys])\n";
      }
      $VAR['Display'] = $align;
      KWL_DrawBlock($VAR);
   }
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/sblock/scroll.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

if (!defined("LOAD_MODULE"))
   die ("You can not access this file directly...");

unset($VAR);
$VAR['Content'] = "";
if ($story) {
   if ($row = SqlResult("SELECT Topic FROM T_Stories WHERE Rid = '$story'")) {
      $VAR['Heading'] = _TOPIC . " : " . $TOPIC[$row]['Topic'];
      $VAR['Content'] .="<b>" . _LAST_STORY . "</b><br />\n";

      $VAR['Content'] .= "<marquee behavior=\"scroll\" direction=\"up\" height=\"100\" scrollamount=\"1\" scrolldelay=\"10\" onmouseover='this.stop()' onmouseout='this.start()'>\n" . KWL_NewStory($story,1) . "</marquee>";

      $VAR['Content'] .= "<hr width=\"95%\" />\n<b>" . _TOP5 . "</b>\n";

      $sql = "SELECT Rid,Heading,replys FROM T_Stories WHERE Topic = $row ORDER by Hits DESC LIMIT 1";
      $A = SqlQueryFetchArray($sql);
      if (is_array($A)) {
         $VAR['Content'] .= "<br />$CONF[dotchar]<a href=\"". KWL_MakeStoryLink($A["Rid"]) ."\">$A[Heading]</a> ($A[replys])\n";
      }

      $sql = "SELECT Rid,Heading,replys FROM T_Stories WHERE Topic = $row ORDER by replys DESC LIMIT 1";
      $A = SqlQueryFetchArray($sql);
      if (is_array($A)) {
         $VAR['Content'] .= "<hr width=\"95%\" /><b>" . _HOT5 . "</b><br />".
                          "$CONF[dotchar]<a href=\"". KWL_MakeStoryLink($A["Rid"]) ."\">$A[Heading]</a> ($A[replys])\n";
      }
      $VAR['Display'] = $align;
      KWL_DrawBlock($VAR);
   }
}
?>
